import datetime
import requests
import time

from crowdcurio_client.crowdcurio import (
    CrowdCurioAPIException, CrowdCurioObject
)

class Experiment(CrowdCurioObject):
    _api_slug = 'experiment'
    _link_slug = 'experiment'
    _edit_attributes = (
        'name',
        'status',
        'params',
        'restrictions',
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, project, curio, task):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Experiment", "id": self.id, "relationships": {"project":{ "data": { "type": "Project", "id": project.id}}, "curio":{ "data": {"type": "Curio", "id": curio.id}}, "task":{ "data": {"type": "Task", "id": task.id}} }}}
        )

    def remove(self, project, curio, task):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Experiment", "id": self.id, "relationships": {"project":{}, "curio":{}, "task":{} }}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Experiment', 'id': self.id}})


class Condition(CrowdCurioObject):
    _api_slug = 'condition'
    _link_slug = 'condition'
    _edit_attributes = (
        'name',
        'configuration',
        'nb_subjects',
        'max_subjects',
        'status',
    )

    @classmethod
    def find(cls, id=''):
        if not id:
            return None
        return cls.where(id=id).next()

    def add(self, experiment):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Condition", "id": self.id, "relationships": {"experiment":{"data":{"type":"Experiment","id":experiment.id}}}}}
        )

    def remove(self, experiment):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Condition", "id": self.id, "relationships": {"experiment":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Condition', 'id': self.id}})


class SubjectCondition(CrowdCurioObject):
    _api_slug = 'subjectcondition'
    _link_slug = 'subjectcondition'
    _edit_attributes = (
        'finished',
        'invalidated',
        'supplementary',
    )

    @classmethod
    def find(cls, id=''):
        if not id:
            return None
        return cls.where(id=id).next()

    def add(self, experiment, condition, user):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "SubjectCondition", "id": self.id, "relationships": {"experiment":{"data":{"type":"Experiment","id":experiment.id}}, "condition":{"data":{"type":"Condition","id":condition.id}}, "user":{"data":{"type":"User","id":user.id}}}}}
        )

    def remove(self, experiment):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "SubjectCondition", "id": self.id, "relationships": {"experiment":{}, "condition":{}, "user":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'SubjectCondition', 'id': self.id}})



class ConfirmationCode(CrowdCurioObject):
    _api_slug = 'experimentconfirmationcode'
    _link_slug = 'experimentconfirmationcode'
    _edit_attributes = (
        'code',
    )

    @classmethod
    def find(cls, id=''):
        if not id:
            return None
        return cls.where(id=id).next()

    def add(self, experiment, user):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "ExperimentConfirmationCode", "id": self.id, "relationships": {"experiment":{"data":{"type":"Experiment","id":experiment.id}}, "user":{"data":{"type":"User","id":user.id}}}}}
        )

    def remove(self, experiment):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "ExperimentConfirmationCode", "id": self.id, "relationships": {"experiment":{}, "user":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'ExperimentConfirmationCode', 'id': self.id}})


class BonusPayment(CrowdCurioObject):
    _api_slug = 'bonus'
    _link_slug = 'bonus'
    _edit_attributes = (
        'code',
    )

    @classmethod
    def find(cls, id=''):
        if not id:
            return None
        return cls.where(id=id).next()

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'BonusPayment', 'id': self.id}})



import datetime
import requests
import time

from crowdcurio_client.crowdcurio import CrowdCurioObject

class Data(CrowdCurioObject):
    _api_slug = 'data'
    _link_slug = 'data'
    _edit_attributes = (
        'slug',
        'name',
        'url',
        'content',
        {}
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Data", "id": self.id, "attributes": {"content": self.content},"relationships": {"dataset":{"data":{"type":"Dataset","id":curio.id}}}}}
        )

    def remove(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Data", "id": self.id, "attributes": {"content": self.content}, "relationships": {"dataset":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Data', 'id': self.id}})

class DataSet(CrowdCurioObject):
    _api_slug = 'dataset'
    _link_slug = 'dataset'
    _edit_attributes = (
        'name',
        'is_active',
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Dataset", "id": self.id, "relationships": {"curio":{"data":{"type":"Curio","id":curio.id}}}}}
        )

    def remove(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Dataset", "id": self.id, "relationships": {"curio":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Dataset', 'id': self.id}})


class DataRecord(CrowdCurioObject):
    _api_slug = 'datarecord'
    _link_slug = 'datarecord'
    _edit_attributes = (
        'seen',
        'order',
        'assigned',
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, task, data, experiment=None, condition=None):
        if experiment is None and condition is None:
            self.put(
                '{}'.format(self.id),
                json={"data": {"type": "Datarecord", "id": self.id, "relationships": {"task":{"data":{"type":"Task","id":task.id}},"data":{"data":{"type":"Data","id":data.id}}}}}
            )
        else:
            self.put(
                '{}'.format(self.id),
                json={"data": {"type": "Datarecord", "id": self.id, "relationships": {"task":{"data":{"type":"Task","id":task.id}},"data":{"data":{"type":"Data","id":data.id}},"experiment":{"data":{"type":"Experiment","id":experiment.id}},"condition":{"data":{"type":"Condition","id":condition.id}}}}}
            )

    def remove(self, task, data, experiment, condition):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Datarecord", "id": self.id, "relationships": {"task":{}, "data":{}, "experiment":{}, "condition":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Datarecord', 'id': self.id}})


from crowdcurio_client.crowdcurio import CrowdCurio
from crowdcurio_client.project import Project
from crowdcurio_client.curio import Curio
from crowdcurio_client.task import Task
from crowdcurio_client.data import Data, DataSet, DataRecord
from crowdcurio_client.resource import Resource
from crowdcurio_client.experiment import Experiment, Condition, SubjectCondition, ConfirmationCode, BonusPayment
from crowdcurio_client.response import Response
from crowdcurio_client.user import User


from setuptools import setup, find_packages

setup(
    name='crowdcurio-client',
    url='https://github.com/crowdcurio/crowdcurio-client',
    author='Alex Williams',
    author_email='alex.williams@uwaterloo.ca',
    version='0.0.9',
    packages=find_packages(),
    include_package_data=True,
    keywords='crowdcurio',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    install_requires=[
        'requests>=2.4.2',
    ],
)



import datetime
import requests
import time

from crowdcurio_client.crowdcurio import CrowdCurioObject

class Response(CrowdCurioObject):
    _api_slug = 'response'
    _link_slug = 'response'
    _edit_attributes = (
        'created',
        'url',
        'content',
    )

    @classmethod
    def find(cls, id=''):
        if not id:
            return None
        return cls.where(id=id, slug=slug).next()



import datetime
import requests
import time

from crowdcurio_client.crowdcurio import (
    CrowdCurioAPIException, CrowdCurioObject
)

class Task(CrowdCurioObject):
    _api_slug = 'task'
    _link_slug = 'task'
    _edit_attributes = (
        'slug',
        'name',
        'type',
        'labels',
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Task", "id": self.id, "relationships": {"curio":{"data":{"type":"Curio","id":curio.id}}}}}
        )

    def remove(self, curio):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Task", "id": self.id, "relationships": {"curio":{}}}}
        )

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Task', 'id': self.id}})


import datetime
import requests
import time

from crowdcurio_client.crowdcurio import CrowdCurioObject

class Resource(CrowdCurioObject):
    _api_slug = 'resource'
    _link_slug = 'resource'
    _edit_attributes = (
        'slug',
        'name',
        'url',
        'class_label',
    )

    @classmethod
    def find(cls, id='', slug=None):
        if not id and not slug:
            return None
        return cls.where(id=id, slug=slug).next()

    def add(self, task):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Resource", "id": self.id, "relationships": {"task":{"data":{"type":"Task","id":task.id}}}}}
        )

    def remove(self, task):
        self.put(
            '{}'.format(self.id),
            json={"data": {"type": "Resource", "id": self.id, "relationships": {"task":{}}}})

    def destroy(self):
        self.delete('{}'.format(self.id), json={'data': {'type':'Resource', 'id': self.id}})